% This matlab file reads the transmission loss data generated by Run Validation - FMM,
% and plots the results in matlab figures.
% The TL from Coustyx is compared with 
%   (a) experiment measurements extracted from the book,
%      "Wu, T.W., editor, Boundary Element Acoustics - Fundamentals
%       and Computer Codes, WIT press, Southampton, Boston, 2000, pp.79-80."

%****************************************************************************
clear all;
% Acoustic medium properties:
%  rho_o = medium density of air = 1.21 kg/m^3
%  c = speed of sound = 343 m/s
rho_o = 1.21;
c = 343;
zo = rho_o*c;

%********************************************************************
%Input:
%  (1) Run "RunValidation - FMM" in the Demo Model before running 
%      this matlab script to obtain file 'validation_results_fmm.txt'
%  (2) Read experimental results, Make sure the 'TL_experiment.txt'
%      provided with the demo model is in the current folder 
%********************************************************************
TL_coustyx = load('validation_results_fmm.txt');
% The results file has 3 columns, where
% TL_coustyx(:,1) = k (wave number)
% TL_coustyx(:,2) = frequency (Hz)
% TL_coustyx(:,3) = transmission loss computed from Coustyx analysis

TL_exp = load('TL_experiment.txt');
% The file has 2 columns, where
% TL_exp(:,1) = frequency (Hz)
% TL_exp(:,2) = transmission loss extracted from the published paper
%********************************************************************

%********************************************************************
%Output:
%  Plot comparisons between FMM and Analytical results
%********************************************************************
figure;
plot(TL_coustyx(:,2), TL_coustyx(:,3), 'k',...
    TL_exp(:,1),TL_exp(:,2),'r');
legend('Coustyx-FMM','Measured');
title('Tranmission Loss Measurements');
xlabel('Frequency (Hz)');
ylabel('TL (dB)');
